OC.L10N.register(
    "core",
    {
    "Please select a file." : "Valitse tiedosto.",
    "File is too big" : "Tiedosto on liian suuri",
    "The selected file is not an image." : "Valittu tiedosto ei ole kuva.",
    "The selected file cannot be read." : "Valittua tiedostoa ei voi lukea.",
    "The file was uploaded" : "Tiedosto lähetettiin",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Ladattu tiedosto on suurempi kuin php.ini-tiedostossa määritelty upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ladattu tiedosto on suurempi kuin HTML-lomakkeessa määritelty MAX_FILE_SIZE",
    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
    "No file was uploaded" : "Tiedostoja ei lähetetty",
    "Missing a temporary folder" : "Väliaikaiskansio puuttuu",
    "Could not write file to disk" : "Ei voitu kirjoittaa levylle",
    "A PHP extension stopped the file upload" : "PHP-laajennus pysäytti tiedoston lähetyksen",
    "Invalid file provided" : "Määritetty virheellinen tiedosto",
    "No image or file provided" : "Kuvaa tai tiedostoa ei määritelty",
    "Unknown filetype" : "Tuntematon tiedostotyyppi",
    "An error occurred. Please contact your admin." : "Tapahtui virhe. Ota yhteys ylläpitoon.",
    "Invalid image" : "Virheellinen kuva",
    "No temporary profile picture available, try again" : "Väliaikaista profiilikuvaa ei ole käytettävissä, yritä uudelleen",
    "No crop data provided" : "Leikkaustietoa ei annettu",
    "No valid crop data provided" : "Kelvollisia leikkaustietoja ei määritetty",
    "Crop is not square" : "Leikkaus ei ole neliö",
    "State token does not match" : "Tilapoletti ei täsmää",
    "Invalid app password" : "Virheellinen sovellussalasana",
    "Could not complete login" : "Kirjautumista ei voitu suorittaa loppuun",
    "Your login token is invalid or has expired" : "Kirjautumispolettisi on virheellinen tai se on vanhentunut",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Tämä Nextcloudin yhteisöjulkaisu ei ole tuettu ja push-ilmoituksia on rajoitettu.",
    "Login" : "Kirjaudu sisään",
    "Unsupported email length (>255)" : "Sähköpostin pituus ei ole tuettu (>255)",
    "Password reset is disabled" : "Salasanan palautus poistettu käytöstä",
    "Could not reset password because the token is expired" : "Salasanaa ei voitu nollata, koska poletti on vanhentunut",
    "Could not reset password because the token is invalid" : "Salasanaa ei voitu nollata, koska poletti on virheellinen",
    "Password is too long. Maximum allowed length is 469 characters." : "Salasana on liian pitkä. Pituus voi olla enintään 469 merkkiä.",
    "%s password reset" : "%s salasanan palautus",
    "Password reset" : "Salasanan palautus",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Paina oheista painiketta palauttaaksesi salasanasi. Jos et ole pyytänyt salasanan palautusta, jätä tämä sähköpostiviesti huomioimatta.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Paina oheista linkkiä palauttaaksesi salasanasi. Jos et ole pyytänyt salasanan palautusta, jätä tämä sähköpostiviesti huomioimatta.",
    "Reset your password" : "Palauta salasanasi",
    "Task not found" : "Tehtävää ei löydy",
    "Internal error" : "Sisäinen virhe",
    "Not found" : "Ei löytynyt",
    "Bad request" : "Virheellinen pyyntö",
    "Image not found" : "Kuvaa ei löytynyt",
    "No translation provider available" : "Käännöksen palveluntarjoaja ei ole saatavilla",
    "Could not detect language" : "Kielen havaitseminen ei onnistunut",
    "Unable to translate" : "Kääntäminen ei onnistu",
    "Nextcloud Server" : "Nextcloud-palvelin",
    "Some of your link shares have been removed" : "Jotkin linkkijakosi on poistettu",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Tietoturvaongelman vuoksi jouduimme poistaa joitakin linkkijakojasi. Lue lisätietoja linkin kautta.",
    "The account limit of this instance is reached." : "Tämän instanssin tiliraja on täynnä.",
    "Learn more ↗" : "Lue lisää ↗",
    "Preparing update" : "Valmistellaan päivitystä",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Korjausvaihe:",
    "Repair info:" : "Korjaustiedot:",
    "Repair warning:" : "Korjausvaroitus:",
    "Repair error:" : "Korjausvirhe:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Käytä komentorivipäivitintä, koska päivitys selainkäyttöliittymällä on estetty config.php-asetustiedostossa.",
    "Turned on maintenance mode" : "Siirrytty huoltotilaan",
    "Turned off maintenance mode" : "Poistuttu huoltotilasta",
    "Maintenance mode is kept active" : "Huoltotila pidetään aktiivisena",
    "Updating database schema" : "Päivitetään tietokannan skeemaa",
    "Updated database" : "Tietokanta päivitetty",
    "Update app \"%s\" from App Store" : "Päivitä sovellus \"%s\" sovelluskaupasta",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tarkistetaan, onko kohteen %s tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
    "Updated \"%1$s\" to %2$s" : "Päivitetty \"%1$s\" versioon %2$s",
    "Set log level to debug" : "Asetettu lokitasoksi vianetsintä",
    "Reset log level" : "Nollattu lokitaso",
    "Starting code integrity check" : "Aloitetaan koodin eheystarkistus",
    "Finished code integrity check" : "Koodin eheystarkistus suoritettu",
    "%s (incompatible)" : "%s (ei yhteensopiva)",
    "The following apps have been disabled: %s" : "Seuraavat sovellukset on poistettu käytöstä: %s",
    "Already up to date" : "Kaikki on jo ajan tasalla",
    "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Lue lisätietoja {linkstart}dokumentaatiosta ↗{linkend}.",
    "unknown text" : "tuntematon teksti",
    "Hello world!" : "Hei maailma!",
    "sunny" : "aurinkoinen",
    "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
    "Hello {name}" : "Hei {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Nämä ovat hakutulokset<script>alert(1)</script></strong>",
    "new" : "uusi",
    "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
    "Update to {version}" : "Päivitä versioon {version}",
    "An error occurred." : "Tapahtui virhe.",
    "Please reload the page." : "Päivitä sivu.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Päivitys epäonnistui. Katso lisätietoja tähän ongelmaan liittyen <a href=\"{url}\">keskustelupalstan viestistä</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Päivitys ei onnistunut. Raportoisitko tämän ongelman <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-yhteisölle</a>.",
    "Continue to {productName}" : "Jatka {productName}iin",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua.","Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua."],
    "Applications menu" : "Sovellusten valikko",
    "Apps" : "Sovellukset",
    "More apps" : "Lisää sovelluksia",
    "_{count} notification_::_{count} notifications_" : ["{count} ilmoitus","{count} ilmoitusta"],
    "No" : "Ei",
    "Yes" : "Kyllä",
    "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
    "Federated user" : "Federoitu käyttäjä",
    "user@your-nextcloud.org" : "käyttäjä@oma-nextcloud.org",
    "Create share" : "Luo jako",
    "Direct link copied to clipboard" : "Suora linkki kopioitu työpöydälle",
    "Please copy the link manually:" : "Kopioi linkki manuaalisesti:",
    "Custom date range" : "Mukautettu päivämääräväli",
    "Pick start date" : "Valitse aloituspäivä",
    "Pick end date" : "Valitse päättymispäivä",
    "Search in current app" : "Etsi nykyisessä sovelluksessa",
    "Clear search" : "Tyhjennä haku",
    "Search everywhere" : "Etsi kaikkialta",
    "Searching …" : "Haetaan…",
    "Start typing to search" : "Aloita kirjoittaminen hakeaksesi",
    "No matching results" : "Ei tuloksia",
    "Today" : "Tänään",
    "Last 7 days" : "Edelliset 7 päivää",
    "Last 30 days" : "Edelliset 30 päivää",
    "This year" : "Tämä vuosi",
    "Last year" : "Viime vuosi",
    "Unified search" : "Yhdistetty haku",
    "Search apps, files, tags, messages" : "Etsi sovelluksia, tiedostoja, tunnisteita, viestejä",
    "Places" : "Sijainnit",
    "Date" : "Päivä",
    "Search people" : "Etsi ihmisiä",
    "People" : "Ihmiset",
    "Filter in current view" : "Suodata nykyisessä näkymässä",
    "Results" : "Tulokset",
    "Load more results" : "Lataa lisää tuloksia",
    "Search in" : "Etsi kohteesta",
    "Log in" : "Kirjaudu sisään",
    "Logging in …" : "Kirjaudutaan sisään...",
    "Log in to {productName}" : "Kirjaudu palveluun {productName}",
    "Wrong login or password." : "Väärä käyttäjätunnus tai salasana.",
    "This account is disabled" : "Tämä tili on poistettu käytöstä",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30 sekunnin päästä.",
    "Account name or email" : "Tilin nimi tai sähköpostiosoite",
    "Account name" : "Tilin nimi",
    "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
    "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
    "Temporary error" : "Väliaikainen virhe",
    "Please try again." : "Yritä uudelleen.",
    "An internal error occurred." : "Tapahtui sisäinen virhe.",
    "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
    "Password" : "Salasana",
    "Log in with a device" : "Kirjaudu laitteella",
    "Login or email" : "Käyttäjätunnus tai sähköposti",
    "Your account is not setup for passwordless login." : "Käyttäjääsi ei ole kytketty käyttämään salasanatonta kirjautumista.",
    "Your connection is not secure" : "Yhteytesi ei ole turvallinen",
    "Passwordless authentication is only available over a secure connection." : "Tunnistautuminen ilman salasanaa on mahdollista vain salattua yhteyttä käyttäessä.",
    "Browser not supported" : "Selain ei ole tuettu",
    "Passwordless authentication is not supported in your browser." : "Selaimesi ei tue tunnistautumista ilman salasanaa.",
    "Reset password" : "Palauta salasana",
    "Back to login" : "Palaa kirjautumiseen",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Jos tämä tili on olemassa, sen sähköpostiosoitteeseen on lähetetty salasanan palautusviesti. Jos et saa viestiä, tarkista sähköpostiosoitteesi ja/tai kirjautumisesi, tarkista roskapostikansiot tai kysy apua paikalliselta järjestelmänvalvojalta.",
    "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
    "Password cannot be changed. Please contact your administrator." : "Salasanaa ei voi vaihtaa. Ole yhteydessä ylläpitäjään.",
    "New password" : "Uusi salasana",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tiedostosi on salattu. Niitä ei ole mahdollista palauttaa kun salasanasi on palautettu. Jos et ole varma mitä tehdä, ota yhteyttä ylläpitäjään ennen kuin jatkat. Oletko varma, että haluat jatkaa?",
    "I know what I'm doing" : "Tiedän mitä teen",
    "Resetting password" : "Salasanan palauttaminen",
    "Schedule work & meetings, synced with all your devices." : "Aikatauluta työsi ja tapaamisesi synkronoidusti kaikkien laitteitesi välillä.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Pidä työkaverisi ja kaverisi samassa paikassa vuotamatta heidän yksityisiä tietojaan.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Yksinkertainen sähköpostisovellus, joka toimii yhdessä Tiedostojen, Kontaktien ja Kalenterin kanssa.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Asiakirjat, laskentataulukot ja esitykset yhteistyönä, taustavoimana Collabora Online.",
    "Distraction free note taking app." : "Häiriötön mustiinpanosovellus.",
    "Recommended apps" : "Suositellut sovellukset",
    "Loading apps …" : "Ladataan sovelluksia…",
    "Could not fetch list of apps from the App Store." : "Sovelluskaupasta ei voitu noutaa listaa sovelluksista.",
    "App download or installation failed" : "Sovelluksen lataus tai asennus epäonnistui",
    "Cannot install this app because it is not compatible" : "Tätä sovellusta ei voi asentaa, koska se ei ole yhteensopiva",
    "Cannot install this app" : "Tätä sovellusta ei voi asentaa",
    "Skip" : "Ohita",
    "Installing apps …" : "Asennetaan sovelluksia…",
    "Install recommended apps" : "Asenna suositellut sovellukset",
    "Settings menu" : "Asetusvalikko",
    "Loading your contacts …" : "Ladataan yhteystietojasi…",
    "Looking for {term} …" : "Etsii {term}…",
    "Search contacts" : "Etsi yhteystietoja",
    "Reset search" : "Tyhjennä haku",
    "Search contacts …" : "Etsi yhteystietoja…",
    "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
    "No contacts found" : "Yhteystietoja ei löytynyt",
    "Show all contacts" : "Näytä kaikki kontaktit",
    "Install the Contacts app" : "Asenna Yhteystiedot-sovellus",
    "Search" : "Etsi",
    "No results for {query}" : "Ei tuloksia haulle {query}",
    "Press Enter to start searching" : "Paina Enter aloittaaksesi haun",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Kirjoita vähintään {minSearchLength} merkki etsiäksesi","Kirjoita vähintään {minSearchLength} merkkiä etsiäksesi"],
    "An error occurred while searching for {type}" : "Haettaessa tyyppiä {type} tapahtui virhe.",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Haku alkaa kun aloitat kirjoittamisen. Tuloksiin on mahdollista siirtyä nuolinäppäimillä",
    "Search for {name} only" : "Etsi vain {name}",
    "Loading more results …" : "Ladataan lisää tuloksia…",
    "Forgot password?" : "Unohditko salasanasi?",
    "Back to login form" : "Takaisin kirjautumisnäkymään",
    "Back" : "Takaisin",
    "Login form is disabled." : "Kirjautumislomake on poistettu käytöstä.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloudin kirjautumislomake on poistettu käytöstä. Käytä toista kirjautumistapaa tai ota yhteys ylläpitoon.",
    "More actions" : "Lisää toimintoja",
    "Security warning" : "Turvallisuusvaroitus",
    "Storage & database" : "Tallennus ja tietokanta",
    "Data folder" : "Datakansio",
    "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
    "For more details check out the documentation." : "Lue lisätiedot ohjeista.",
    "Performance warning" : "Suorituskykyvaroitus",
    "You chose SQLite as database." : "Valitsit SQLiten tietokannaksi.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite tulisi ottaa käyttöön vain minimaalisissa kehitysympäristöissä. Tuotantokäyttöön suosittelemme toista tietokantaratkaisua.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jos käytät asiakasohjelmia tiedostojen synkronointiin, SQLiten käyttöä ei suositella.",
    "Database user" : "Tietokannan käyttäjä",
    "Database password" : "Tietokannan salasana",
    "Database name" : "Tietokannan nimi",
    "Database tablespace" : "Tietokannan taulukkotila",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Määritä portin numero tietokantapalvelimen yhteydessä (esim. localhost:5432).",
    "Database host" : "Tietokantapalvelin",
    "Installing …" : "Asennetaan …",
    "Install" : "Asenna",
    "Need help?" : "Tarvitsetko apua?",
    "See the documentation" : "Tutustu ohjeisiin",
    "{name} version {version} and above" : "Selaimen {name} versio {version} ja uudempi",
    "This browser is not supported" : "Tämä selain ei ole tuettu",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Selaimesi ei ole tuettu. Päivitä uudempaan versioon tai muuhun tuettuun selaimeen.",
    "Continue with this unsupported browser" : "Jatka tällä tuen ulkopuolella olevalla selaimella",
    "Supported versions" : "Tuetut versiot",
    "Search {types} …" : "Etsi {types}…",
    "Choose {file}" : "Valitse {file}",
    "Choose" : "Valitse",
    "Copy to {target}" : "Kopioi kohteeseen {target}",
    "Copy" : "Kopioi",
    "Move to {target}" : "Siirrä kohteeseen {target}",
    "Move" : "Siirrä",
    "OK" : "OK",
    "read-only" : "vain luku",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tiedoston ristiriita","{count} tiedoston ristiriita"],
    "One file conflict" : "Yhden tiedoston ristiriita",
    "New Files" : "Uudet tiedostot",
    "Already existing files" : "Jo olemassa olevat tiedostot",
    "Which files do you want to keep?" : "Mitkä tiedostot haluat säilyttää?",
    "If you select both versions, the copied file will have a number added to its name." : "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
    "Cancel" : "Peruuta",
    "Continue" : "Jatka",
    "(all selected)" : "(kaikki valittu)",
    "({count} selected)" : "({count} valittu)",
    "Error loading file exists template" : "Virhe ladatessa mallipohjaa",
    "Saving …" : "Tallennetaan…",
    "seconds ago" : "sekunteja sitten",
    "Connection to server lost" : "Yhteys palvelimelle katkesi",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
    "Add to a project" : "Lisää projektiin",
    "Show details" : "Näytä tiedot",
    "Hide details" : "Piilota tiedot",
    "Rename project" : "Nimeä projekti uudelleen",
    "Failed to rename the project" : "Projektin nimeäminen uudelleen epäonnistui",
    "Failed to create a project" : "Projektin luominen epäonnistui",
    "Failed to add the item to the project" : "Kohteen lisääminen projektiin epäonnistui",
    "Connect items to a project to make them easier to find" : "Yhdistä kohteita projektiin tehdäksesi niiden löytämisestä helpompaa",
    "Type to search for existing projects" : "Kirjoita etsiäksesi olemassa olevia projekteja",
    "New in" : "Uutta versiossa",
    "View changelog" : "Katso muutosloki",
    "No action available" : "Toimintoa ei saatavilla",
    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
    "Close \"{dialogTitle}\" dialog" : "Sulje \"{dialogTitle}\"-ikkuna",
    "Email length is at max (255)" : "Sähköpostin pituus on maksimissaan (255)",
    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
    "Restricted" : "Rajoitettu",
    "Invisible" : "Näkymätön",
    "Delete" : "Poista",
    "Rename" : "Nimeä uudelleen",
    "Collaborative tags" : "Yhteistyölliset tunnisteet",
    "No tags found" : "Tunnisteita ei löytynyt",
    "Clipboard not available, please copy manually" : "Leikepöytä ei ole saatavilla, kopioi manuaalisesti",
    "Personal" : "Henkilökohtainen",
    "Accounts" : "Tilit",
    "Admin" : "Ylläpito",
    "Help" : "Ohje",
    "Access forbidden" : "Pääsy estetty",
    "Page not found" : "Sivua ei löytynyt",
    "The page could not be found on the server or you may not be allowed to view it." : "Sivua ei löytynyt palvelimelta, tai sinulla ei ole oikeutta nähdä sitä.",
    "Back to %s" : "Takaisin kohtaan %s",
    "Too many requests" : "Liian monta pyyntöä",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Verkostasi tehtiin liian monta pyyntöä. Yritä myöhemmin uudelleen tai ole yhteydessä ylläpitäjään, jos tämä on mielestäsi virhe.",
    "Error" : "Virhe",
    "Internal Server Error" : "Sisäinen palvelinvirhe",
    "The server was unable to complete your request." : "Palvelin ei kyennyt käsittelemään pyyntöäsi.",
    "If this happens again, please send the technical details below to the server administrator." : "Jos tämä tapahtuu uudelleen, lähetä alla olevat tekniset tiedot palvelimen ylläpitäjälle.",
    "More details can be found in the server log." : "Lisätietoja on palvelimen lokitiedostossa.",
    "For more details see the documentation ↗." : "Lisätietoja on dokumentaatiossa ↗.",
    "Technical details" : "Tekniset tiedot",
    "Remote Address: %s" : "Etäosoite: %s",
    "Request ID: %s" : "Pyynnön tunniste: %s",
    "Type: %s" : "Tyyppi: %s",
    "Code: %s" : "Koodi: %s",
    "Message: %s" : "Viesti: %s",
    "File: %s" : "Tiedosto: %s",
    "Line: %s" : "Rivi: %s",
    "Trace" : "Jälki",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Vaikuttaa siltä, että yrität Nextcloudin uudelleenasennusta. Tiedosto CAN_INSTALL puuttuu asetuskansiosta. Ole hyvä ja luo tiedosto CAN_INSTALL asetuskansioon jatkaaksesi.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Tiedostoa CAN_INSTALL ei voitu poistaa asetuskansiosta. Poista tiedosto manuaalisesti.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tämä sovellus vaatii toimiakseen JavaScript-tuen. {linkstart}Ota JavaScript käyttöön{linkend} ja päivitä sivu.",
    "Skip to main content" : "Siirry pääsisältöön",
    "Skip to navigation of app" : "Hyppää sovelluksen navigointiin.",
    "Go to %s" : "Siirry %s§",
    "Get your own free account" : "Hanki ilmainen tili itsellesi",
    "Connect to your account" : "Yhdistä tiliisi",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jos et ole asentamassa uutta laitetta tai sovellusta, joku yrittää huijata sinut antamaan käyttöoikeudet tietoihisi. Tässä tapauksessa älä jatka, ota yhteys järjestelmänvalvojaan.",
    "App password" : "Sovellussalasana",
    "Grant access" : "Myönnä pääsy",
    "Alternative log in using app password" : "Vaihtoehtoinen kirjautuminen käyttäen sovellussalasanaa",
    "Account access" : "Tilin käyttö",
    "Currently logged in as %1$s (%2$s)." : "Kirjautuneena käyttäjänä %1$s (%2$s).",
    "Account connected" : "Tili yhdistetty",
    "Your client should now be connected!" : "Päätteesi pitäisi olla yhdistetty!",
    "You can close this window." : "Voit sulkea tämän ikkunan.",
    "Previous" : "Edellinen",
    "This share is password-protected" : "Jako on salasanasuojattu",
    "The password is wrong or expired. Please try again or request a new one." : "Salasana on väärä tai vanhentunut. Yritä uudelleen tai pyydä uusi salasana.",
    "Please type in your email address to request a temporary password" : "Kirjoita sähköpostiosoitteesi pyytääksesi väliaikaista salasanaa",
    "Email address" : "Sähköpostiosoite",
    "Password sent!" : "Salasana lähetetty!",
    "You are not authorized to request a password for this share" : "Sinulla ei ole valtuutta pyytää salasanaa tähän jakoon",
    "Two-factor authentication" : "Kaksivaiheinen tunnistautuminen",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Tilisi tietoturvatasoa on korotettu. Käytä kaksivaiheista tunnistautumista:",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Ole yhteydessä ylläpitoon saadaksesi apua.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Jatka asettaaksesi kaksivaiheisen tunnistautumisen.",
    "Set up two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
    "Use backup code" : "Käytä varakoodia",
    "Cancel login" : "Peru kirjautuminen",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Parannettu suojaus on käytössä käyttäjätilissäsi. Valitse asennettava tarjoaja:",
    "Error while validating your second factor" : "Tunnistuksen toisen vaiheen tarkistus epäonnistui",
    "Access through untrusted domain" : "Käyttö epäluotettavasta toimialueesta",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ota yhteys ylläpitoon, tai jos olet tämän palvelun ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tiedostossa config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Lisätietoa tämän määrittämisestä löydät %1$sdokumentaatiosta%2$s.",
    "App update required" : "Sovelluksen päivittäminen vaaditaan",
    "%1$s will be updated to version %2$s" : "%1$s päivitetään versioon %2$s",
    "The following apps will be updated:" : "Seuraavat sovellukset päivitetään:",
    "These incompatible apps will be disabled:" : "Nämä yhteensopimattomat sovellukset poistetaan käytöstä:",
    "The theme %s has been disabled." : "Teema %s on poistettu käytöstä.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
    "Start update" : "Käynnistä päivitys",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
    "Detailed logs" : "Yksityiskohtainen loki",
    "Update needed" : "Päivitys vaaditaan",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Käytä komentorivin päivitysohjelmaa, koska sinulla on suuri palvelininstanssi (yli 50 tiliä).",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Jos tarvitset apua, katso <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ohjeista</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tiedän että jos jatkan päivittämistä web-liittymän kautta, saatan menettää kaikki tiedostot, mikäli päivitys epäonnistuu. Onneksi olen tehnyt varmuuskopion ja osaan sen myös palauttaa tarvittaessa.",
    "Upgrade via web on my own risk" : "Internetin kautta päivittäminen omalla vastuulla",
    "Maintenance mode" : "Huoltotila",
    "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
    "This page will refresh itself when the instance is available again." : "Tämä sivu päivittyy itsestään, kun instanssi on jälleen käytettävissä.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
    "Currently open" : "Parhaillaan avoinna",
    "Login with username or email" : "Kirjaudu käyttäjätunnuksella tai sähköpostiosoitteella",
    "Login with username" : "Kirjaudu käyttäjätunnuksella",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Keskustelu, videopuhelut, näytön jako, verkkotapaamiset ja web-konferenssit - selaimessasi ja puhelinsovelluksilla.",
    "You have not added any info yet" : "Et ole lisännyt tietoja vielä",
    "{user} has not added any info yet" : "{user} ei ole lisännyt tietoja vielä",
    "Edit Profile" : "Muokkaa profiilia",
    "The headline and about sections will show up here" : "Otsikko ja listätieto-osiot näkyvät tässä",
    "Error loading message template: {error}" : "Virhe ladatessa viestipohjaa: {error}",
    "Very weak password" : "Erittäin heikko salasana",
    "Weak password" : "Heikko salasana",
    "So-so password" : "Kohtalainen salasana",
    "Good password" : "Hyvä salasana",
    "Strong password" : "Vahva salasana",
    "Profile not found" : "Profiilia ei löytynyt",
    "The profile does not exist." : "Profiilia ei ole olemassa",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska .htaccess-tiedosto ei toimi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Lisätietoja palvelimen kunnollisista asetuksista on <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ohjeissa</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Luo ylläpitäjän tili</strong>",
    "New admin account name" : "Uuden ylläpitäjän tilin nimi",
    "New admin password" : "Uuden ylläpitäjän salasana",
    "Show password" : "Näytä salasana",
    "Toggle password visibility" : "Näytä/piilota salasana",
    "Configure the database" : "Määritä tietokanta",
    "Only %s is available." : "Vain %s on käytettävissä.",
    "Database account" : "Tietokantatili"
},
"nplurals=2; plural=(n != 1);");
